@@ -348,6 +348,7 @@ class WorkRole(admin.ModelAdmin):
 
 @admin.register(models.Agreement)
 class Agreement(admin.ModelAdmin):
-    list_display = ('id', '__str__', 'company', 'cancelled_flag',
-                    'bill_time', 'work_type', 'work_role')
+    list_display = ('id', '__str__', 'company', 'agreement_status',
+                    'cancelled_flag', 'bill_time', 'work_type', 'work_role')
+    list_filter = ['agreement_status', 'company']
     search_fields = ['name']
